// --------------------------------------------------------------------------------------------------
// PARAMETERS:
// --------------------------------------------------------------------------------------------------

//transforms
float4x4 tW: WORLD;        //the models world matrix
float4x4 tV: VIEW;         //view matrix as set via Renderer (EX9)
float4x4 tP: PROJECTION;
float4x4 tWVP: WORLDVIEWPROJECTION;

//texture
texture TexCurseur <string uiname="Curseur Texture";>;
sampler SampCurseur = sampler_state    
{
    Texture   = (TexCurseur);          
    MipFilter = LINEAR;        
    MinFilter = LINEAR;
    MagFilter = LINEAR;
};

//texture
texture TexMask <string uiname="Mask";>;
sampler SampMask = sampler_state    
{
    Texture   = (TexMask);          
    MipFilter = LINEAR;        
    MinFilter = LINEAR;
    MagFilter = LINEAR;
};



//texture transformation marked with semantic TEXTUREMATRIX to achieve symmetric transformations
float4x4 tTex: TEXTUREMATRIX <string uiname="Texture Transform";>;

struct vs2ps
{ 
    float4 Pos  : POSITION;
    float2 TexCd : TEXCOORD0;
};


// --------------------------------------------------------------------------------------------------
// VERTEXSHADERS
// --------------------------------------------------------------------------------------------------
vs2ps VS(
    float4 PosO  : POSITION,
    float4 TexCd : TEXCOORD0)
{
    //declare output struct
    vs2ps Out;

    //transform position
    Out.Pos = mul(PosO, tWVP);
    
    //transform texturecoordinates
    Out.TexCd = mul(TexCd, tTex);

    return Out;
}



// --------------------------------------------------------------------------------------------------
// PIXELSHADERS:
// --------------------------------------------------------------------------------------------------

float CurseurOffset = 0.05;
float4 PS(vs2ps In): COLOR
{
	//just the red channel channel from R32F texure in the texture 
    float curseur = tex2D(SampCurseur, In.TexCd).r;
	float4 mask = tex2D(SampMask, In.TexCd);

	if (all(mask.rgb >= 1))
	{
		curseur += CurseurOffset;
	}
	
	curseur = saturate(curseur);
	
	//just write curseur value into red channel of the output
	return float4(curseur, 0, 0, 1); //clamp curseur value to 0..1 
}

// --------------------------------------------------------------------------------------------------
// TECHNIQUES:
// --------------------------------------------------------------------------------------------------

technique TSimpleShader
{
    pass P0
    {
        //Wrap0 = U;  // useful when mesh is round like a sphere
        VertexShader = compile vs_1_1 VS();
        PixelShader  = compile ps_3_0 PS();
    }
} 